//----------------------------------------------------------------------------------------------------
//
//	WrapperInspector
//
//	Inherits From:		WMInspector
//
//	Declared In:		WrapperInspector.h
//
//	Class Description
//
//		WrapperInspector manages inspection of 'bundled' WM files.
//		WrapperInspector is the class registered with WM to inspect
//		files with extensions such as 'app', 'bundle', 'rtfd', etc.  The
//		file bundle.registry contains all WM registration information.  
//
//		WrapperInspector displays the contents of the 'wrapped' WM
//		file in a browser.  'Sub' Inspectors provide simple inspection
//		of these files when you select from this browser.
//
//		SubInspectors work on specific file extensions.  An 
//		NXStringTable is used to hold extension/subinspector class
//		registration.  For example, 'eps', and 'tiff' are keys in the 
//		string table, ImageSubInspector is the value.  It represents the
//		subinspector class name that will in turn be messaged to 
//		provide inspection when an 'eps' or 'tiff' is selected.  You may 
//		add new subinspectors and/or register new extensions.
//
//	Disclaimer
//
//		You may freely copy, distribute and reuse this software and its
//		associated documentation. I disclaim any warranty of any kind, 
//		expressed or implied, as to its fitness for any particular use.
//
//----------------------------------------------------------------------------------------------------
#import <appkit/appkit.h>
#import <apps/Workspace.h>

@interface WrapperInspector:WMInspector
{
	id	splitView;		//  NXSplitView for browser/subinspectors.
	id	browser;			//  File Browser.
	id	inspectorView;	//  Where Inspector Views will be displayed.
	id	subPathText;		//  TextField for current path.

	id	messageView;	//  View for generic message display.
	id	messageText;		//  TextField for generic messages.

	id	inspectorStrings;	//  NXStringTable with SubInspector classnames.
}

//----------------------------------------------------------------------------------------------------
//  Action Methods
//----------------------------------------------------------------------------------------------------
- fileSelected: sender;
- open: sender;
- openAsFolder:sender;


//----------------------------------------------------------------------------------------------------
//  Inspection Methods
//----------------------------------------------------------------------------------------------------
- inspect: (STR)currentPath usingInspectorClass: (STR)inspectorClass;
- noInspector;
- selectionNotADirectory;


//----------------------------------------------------------------------------------------------------
//  Selection Path Methods
//----------------------------------------------------------------------------------------------------
- (STR) currentPath;
- (STR) extension: (const char*) path;
- (BOOL)isDirectory;
- updateSubPath;


//----------------------------------------------------------------------------------------------------
//  Browser Delegate Method
//----------------------------------------------------------------------------------------------------
- (int) browser: aBrowser fillMatrix: aMatrix inColumn: (int)aColumn;


@end
